@@ -3,11 +3,14 @@ from __future__ import print_function, division, absolute_import
 
 from os.path import dirname, abspath
 import unittest
+#from . import types
 
 from pykit.configuration import config
-from pykit.parsing import from_c
+#from pykit.parsing import from_c
 
-__version__ = '0.1'
+from ._version import get_versions
+__version__ = get_versions()['version']
+del get_versions
 
 # ______________________________________________________________________
 # pykit.test()
