@@ -12,21 +12,28 @@ def find_handler(setup_handlers, exc_model, exc):
         for block in handler_blocks:
             for op in findallops(block.leaders, 'exc_catch'):
                 [exc_types] = op.args
-                if any(exc_model.exc_match(exc_type.const, exc)
+                if any(exc_model.exc_op_match(exc_type, exc)
                            for exc_type in exc_types):
                     return op.block
 
 
-def run(func, env, exc_model=interp.ExceptionModel()):
+def rewrite_exceptions(func, env, exc_model=interp.ExceptionModel()):
+    """
+    Rewrite exc_throw(exc) -> jump(handler_block) for statically determined
+    exceptions.
+
+    TODO: Can this be optimized instead after lowering to a zero-cost or
+          costful model?
+    """
     b = OpBuilder()
     for op in func.ops:
         if op.opcode != 'exc_throw':
             continue
         [exc] = op.args
-        if not isinstance(exc, Const):
-            continue
-
         setup_handlers = findallops(op.block.leaders, 'exc_setup')
-        handler = find_handler(setup_handlers, exc_model, exc.const)
+        handler = find_handler(setup_handlers, exc_model, exc)
         if handler:
-            op.replace(b.jump(handler, result=op.result))
\ No newline at end of file
+            op.replace(b.jump(handler, result=op.result))
+
+
+run = rewrite_exceptions
\ No newline at end of file
