@@ -2,4 +2,4 @@ from .pattern import match
 from .traits import traits, Delegate
 from .convenience import (ValueDict, nestedmap, flatten, map, invert, hashable,
                           cached, call_once, mergedicts, listify, prefix,
-                          substitute, make_temper)
\ No newline at end of file
+                          substitute, make_temper, listitems)
\ No newline at end of file
